Plants for a Future
===================

`PFAF`_ is a resource and information centre for edible and otherwise
useful plants. It provides a proprietary database that is available
for download from their website. To use this database, you need to
run the following command once you receive the Excel file:

.. code-block:: text

    > permaculture store plants-for-a-future <path to xls file>

Where ``<path to xls file>`` should be replaced with the actual path to the Excel file.

.. _PFAF: https://pfaf.org/
